@@ -105,7 +105,7 @@ class ContactRecord(NamedTuple):
     """
 
     kind: str
-    """Supported values: C{email}, C{slack}, C{phone}, C{rest}."""
+    """Supported values: C{email}, C{slack}, C{phone}, C{REST}."""
 
     tstamp: str
     """Timestamp of the record creation in UTC, formatted according to ISO-8601."""
@@ -1031,17 +1031,17 @@ class RequestMessageSms(NamedTuple):
 
 class RequestMessageRest(NamedTuple):
     """
-    Represents the data payload for a C{rest} channel C{MESSAGE} request.
+    Represents the data payload for a C{REST} channel C{MESSAGE} request.
     """
 
     sender: str
-    """The sender of the rest channel message."""
+    """The sender of the C{REST} channel message."""
 
     receiver: str
-    """The receiver of the rest channel message."""
+    """The receiver of the C{REST} channel message."""
 
     text: str
-    """The text content of the rest channel message."""
+    """The text content of the C{REST} channel message."""
 
 
 RequestMessage = Union[RequestMessageSlack, RequestMessageEmail, RequestMessageSms, RequestMessageRest]
@@ -1188,17 +1188,17 @@ class ResponseMessageSms(NamedTuple):
 
 class ResponseMessageRest(NamedTuple):
     """
-    Represents the data payload for the response to a C{rest} channel C{MESSAGE} request.
+    Represents the data payload for the response to a C{REST} channel C{MESSAGE} request.
     """
 
     sender: str
-    """The sender of the rest channel message."""
+    """The sender of the C{REST} channel message."""
 
     receiver: str
-    """The receiver of the rest channel message."""
+    """The receiver of the C{REST} channel message."""
 
     text: str
-    """The text content of the rest channel message."""
+    """The text content of the C{REST} channel message."""
 
     @classmethod
     def make(
